@@ -1,6 +1,7 @@
 import os.path
 import shutil
 import time
+import sys
 from pathlib import Path
 
 from pycopy import logging
@@ -78,9 +79,6 @@ class Syncer:
             self.dst_hashes.update_hash(path, self.src_hashes)
 
     def check_hashes(self, path: Path) -> bool:
-        eq = "==" if (self.src_hashes.get_hash(path)
-                      != self.dst_hashes.get_hash(path)) else "!="
-        print(f"{self.src_hashes.get_hash(path)} {eq} {self.dst_hashes.get_hash(path)}")
         return (self.src_hashes.get_hash(path)
                 != self.dst_hashes.get_hash(path))
 
@@ -107,6 +105,7 @@ class Syncer:
 
         if not self.use_hashes:
             return
+        print(time.time())
         if (not force) or time.time() - self.last_autosave_time < 2:
             return
 
@@ -114,6 +113,7 @@ class Syncer:
 
         terminal_formatting.print_temp(f"Saving hashes to {self.hash_file}")
         self.hash_file.write_text(self.dst_hashes.serialise())
+        sys.exit()
 
     def visit_file(self, path: Path):
         src = self.src / path
